@@ -16,12 +16,16 @@
 #include "c.h"
 
 #include "nodes/pg_list.h"
+#include "utils/array.h"
+#include "utils/hsearch.h"
 
 
 /* utility functions declaration shared within this module */
 extern List * SortList(List *pointerList,
 					   int (*ComparisonFunction)(const void *, const void *));
 extern void ** PointerArrayFromList(List *pointerList);
-
+extern ArrayType * DatumArrayToArrayType(Datum *datumArray, int datumCount,
+										 Oid datumTypeId);
+extern HTAB * ListToHashSet(List *pointerList, Size keySize, bool isStringList);
 
 #endif /* CITUS_LISTUTILS_H */
