@@ -24,6 +24,8 @@
 #define DISABLE_LIMIT_APPROXIMATION -1
 #define DISABLE_DISTINCT_APPROXIMATION 0.0
 #define ARRAY_CAT_AGGREGATE_NAME "array_cat_agg"
+#define JSONB_CAT_AGGREGATE_NAME "jsonb_cat_agg"
+#define JSON_CAT_AGGREGATE_NAME "json_cat_agg"
 #define WORKER_COLUMN_FORMAT "worker_column_%d"
 
 /* Definitions related to count(distinct) approximations */
@@ -36,6 +38,11 @@
 #define HLL_ADD_AGGREGATE_NAME "hll_add_agg"
 #define HLL_UNION_AGGREGATE_NAME "hll_union_agg"
 #define HLL_CARDINALITY_FUNC_NAME "hll_cardinality"
+#define HLL_FORCE_GROUPAGG_GUC_NAME "hll.force_groupagg"
+
+/* Definitions related to Top-N approximations */
+#define TOPN_ADD_AGGREGATE_NAME "topn_add_agg"
+#define TOPN_UNION_AGGREGATE_NAME "topn_union_agg"
 
 
 /*
@@ -55,7 +62,20 @@ typedef enum
 	AGGREGATE_MAX = 3,
 	AGGREGATE_SUM = 4,
 	AGGREGATE_COUNT = 5,
-	AGGREGATE_ARRAY_AGG = 6
+	AGGREGATE_ARRAY_AGG = 6,
+	AGGREGATE_JSONB_AGG = 7,
+	AGGREGATE_JSONB_OBJECT_AGG = 8,
+	AGGREGATE_JSON_AGG = 9,
+	AGGREGATE_JSON_OBJECT_AGG = 10,
+	AGGREGATE_BIT_AND = 11,
+	AGGREGATE_BIT_OR = 12,
+	AGGREGATE_BOOL_AND = 13,
+	AGGREGATE_BOOL_OR = 14,
+	AGGREGATE_EVERY = 15,
+	AGGREGATE_HLL_ADD = 16,
+	AGGREGATE_HLL_UNION = 17,
+	AGGREGATE_TOPN_ADD_AGG = 18,
+	AGGREGATE_TOPN_UNION_AGG = 19
 } AggregateType;
 
 
@@ -96,8 +116,13 @@ typedef enum
  * values in the preceding AggregateType enum. This order needs to be preserved.
  */
 static const char *const AggregateNames[] = {
-	"invalid", "avg", "min", "max", "sum",
-	"count", "array_agg"
+	"invalid", "avg", "min", "max",
+	"sum", "count", "array_agg",
+	"jsonb_agg", "jsonb_object_agg",
+	"json_agg", "json_object_agg",
+	"bit_and", "bit_or", "bool_and", "bool_or", "every",
+	"hll_add_agg", "hll_union_agg",
+	"topn_add_agg", "topn_union_agg"
 };
 
 
@@ -112,20 +137,15 @@ extern void MultiLogicalPlanOptimize(MultiTreeRoot *multiTree);
 /* Function declaration for getting partition method for the given relation */
 extern char PartitionMethod(Oid relationId);
 
-/* Function declaration for getting oid for the given function name */
-extern Oid FunctionOid(const char *schemaName, const char *functionName,
-					   int argumentCount);
-
 /* Function declaration for helper functions in subquery pushdown */
+extern bool GroupedByColumn(List *groupClauseList, List *targetList, Var *column);
 extern List * SubqueryMultiTableList(MultiNode *multiNode);
 extern List * GroupTargetEntryList(List *groupClauseList, List *targetEntryList);
 extern bool ExtractQueryWalker(Node *node, List **queryList);
-extern bool LeafQuery(Query *queryTree);
-extern List * PartitionColumnOpExpressionList(Query *query);
-extern List * ReplaceColumnsInOpExpressionList(List *opExpressionList, Var *newColumn);
 extern bool IsPartitionColumn(Expr *columnExpression, Query *query);
 extern void FindReferencedTableColumn(Expr *columnExpression, List *parentQueryList,
 									  Query *query, Oid *relationId, Var **column);
 
+extern bool IsGroupBySubsetOfDistinct(List *groupClause, List *distinctClause);
 
 #endif   /* MULTI_LOGICAL_OPTIMIZER_H */
