@@ -14,6 +14,7 @@
 #include "access/sdir.h"
 #include "distributed/multi_executor.h"
 #include "distributed/multi_physical_planner.h"
+#include "distributed/placement_connection.h"
 #include "executor/execdesc.h"
 #include "executor/tuptable.h"
 #include "nodes/pg_list.h"
@@ -35,13 +36,24 @@ typedef struct XactShardConnSet
 extern bool AllModificationsCommutative;
 extern bool EnableDeadlockPrevention;
 
+/* number of nested stored procedure call levels we are currently in */
+extern int StoredProcedureLevel;
+
+
 extern void CitusModifyBeginScan(CustomScanState *node, EState *estate, int eflags);
-extern TupleTableSlot * RouterSingleModifyExecScan(CustomScanState *node);
 extern TupleTableSlot * RouterSelectExecScan(CustomScanState *node);
-extern TupleTableSlot * RouterMultiModifyExecScan(CustomScanState *node);
+extern TupleTableSlot * RouterModifyExecScan(CustomScanState *node);
+
+extern void ExecuteMultipleTasks(CitusScanState *scanState, List *taskList,
+								 bool isModificationQuery, bool expectResults);
 
 extern int64 ExecuteModifyTasksWithoutResults(List *taskList);
-extern void ExecuteTasksSequentiallyWithoutResults(List *taskList);
+extern int64 ExecuteModifyTasksSequentiallyWithoutResults(List *taskList,
+														  CmdType operation);
 
+/* helper functions */
+extern bool TaskListRequires2PC(List *taskList);
+extern List * BuildPlacementSelectList(uint32 groupId, List *relationShardList);
+extern List * BuildPlacementDDLList(uint32 groupId, List *relationShardList);
 
 #endif /* MULTI_ROUTER_EXECUTOR_H_ */
