@@ -11,6 +11,7 @@
 #define REMOTE_TRANSACTION_H
 
 
+#include "libpq-fe.h"
 #include "nodes/pg_list.h"
 #include "lib/ilist.h"
 
@@ -79,6 +80,11 @@ typedef struct RemoteTransaction
 } RemoteTransaction;
 
 
+/* utility functions for dealing with remote transactions */
+extern bool ParsePreparedTransactionName(char *preparedTransactionName, int *groupId,
+										 int *procId, uint64 *transactionNumber,
+										 uint32 *connectionNumber);
+
 /* change an individual remote transaction's state */
 extern void StartRemoteTransactionBegin(struct MultiConnection *connection);
 extern void FinishRemoteTransactionBegin(struct MultiConnection *connection);
@@ -102,9 +108,14 @@ extern void RemoteTransactionBeginIfNecessary(struct MultiConnection *connection
 extern void RemoteTransactionsBeginIfNecessary(List *connectionList);
 
 /* other public functionality */
+extern void HandleRemoteTransactionConnectionError(struct MultiConnection *connection,
+												   bool raiseError);
+extern void HandleRemoteTransactionResultError(struct MultiConnection *connection,
+											   PGresult *result, bool raiseErrors);
 extern void MarkRemoteTransactionFailed(struct MultiConnection *connection,
 										bool allowErrorPromotion);
 extern void MarkRemoteTransactionCritical(struct MultiConnection *connection);
+extern bool IsRemoteTransactionCritical(struct MultiConnection *connection);
 
 
 /*
@@ -119,6 +130,7 @@ extern void ResetRemoteTransaction(struct MultiConnection *connection);
 extern void CoordinatedRemoteTransactionsPrepare(void);
 extern void CoordinatedRemoteTransactionsCommit(void);
 extern void CoordinatedRemoteTransactionsAbort(void);
+extern void CheckRemoteTransactionsHealth(void);
 
 /* remote savepoint commands */
 extern void CoordinatedRemoteTransactionsSavepointBegin(SubTransactionId subId);
