@@ -15,6 +15,28 @@ BEGIN
 END;
 $$;
 
+/*****************************************************************************
+ * Enable SSL to encrypt all trafic by default
+ *****************************************************************************/
+-- create temporary UDF that has the power to change settings within postgres and drop it
+-- after ssl has been setup.
+CREATE FUNCTION citus_setup_ssl()
+    RETURNS void
+    LANGUAGE C STRICT
+    AS 'MODULE_PATHNAME', $$citus_setup_ssl$$;
+
+DO LANGUAGE plpgsql
+$$
+BEGIN
+    -- setup ssl when postgres is OpenSSL-enabled
+    IF current_setting('ssl_ciphers') != 'none' THEN
+        PERFORM citus_setup_ssl();
+    END IF;
+END;
+$$;
+
+DROP FUNCTION citus_setup_ssl();
+
 /*****************************************************************************
  * Citus data types
  *****************************************************************************/
@@ -219,28 +241,6 @@ COMMENT ON FUNCTION worker_fetch_partition_file(bigint, integer, integer, intege
                                                 integer)
     IS 'fetch partition file from remote node';
 
-CREATE FUNCTION worker_fetch_query_results_file(bigint, integer, integer, text, integer)
-    RETURNS void
-    LANGUAGE C STRICT
-    AS 'MODULE_PATHNAME', $$worker_fetch_query_results_file$$;
-COMMENT ON FUNCTION worker_fetch_query_results_file(bigint, integer, integer, text,
-                                                    integer)
-    IS 'fetch query results file from remote node';
-
-CREATE FUNCTION worker_fetch_foreign_file(text, bigint, text[], integer[])
-    RETURNS void
-    LANGUAGE C STRICT
-    AS 'MODULE_PATHNAME', $$worker_fetch_foreign_file$$;
-COMMENT ON FUNCTION worker_fetch_foreign_file(text, bigint, text[], integer[])
-    IS 'fetch foreign file from remote node and apply file';
-
-CREATE FUNCTION worker_fetch_regular_table(text, bigint, text[], integer[])
-    RETURNS void
-    LANGUAGE C STRICT
-    AS 'MODULE_PATHNAME', $$worker_fetch_regular_table$$;
-COMMENT ON FUNCTION worker_fetch_regular_table(text, bigint, text[], integer[])
-    IS 'fetch PostgreSQL table from remote node';
-
 CREATE FUNCTION worker_range_partition_table(bigint, integer, text, text, oid, anyarray)
     RETURNS void
     LANGUAGE C STRICT
@@ -278,20 +278,6 @@ CREATE FUNCTION worker_cleanup_job_schema_cache()
 COMMENT ON FUNCTION worker_cleanup_job_schema_cache()
     IS 'cleanup all job schemas in current database';
 
-CREATE FUNCTION worker_foreign_file_path(text)
-    RETURNS text
-    LANGUAGE C STRICT
-    AS 'MODULE_PATHNAME', $$worker_foreign_file_path$$;
-COMMENT ON FUNCTION worker_foreign_file_path(text)
-    IS 'get a foreign table''s local file path';
-
-CREATE FUNCTION worker_find_block_local_path(bigint, text[])
-    RETURNS text
-    LANGUAGE C STRICT
-    AS 'MODULE_PATHNAME', $$worker_find_block_local_path$$;
-COMMENT ON FUNCTION worker_find_block_local_path(bigint, text[])
-    IS 'find an HDFS block''s local file path';
-
 CREATE FUNCTION worker_apply_shard_ddl_command(bigint, text)
     RETURNS void
     LANGUAGE C STRICT
@@ -854,3 +840,218 @@ ALTER TABLE citus.pg_dist_local_group SET SCHEMA pg_catalog;
 GRANT SELECT ON pg_catalog.pg_dist_local_group TO public;
 
 ALTER TABLE pg_catalog.pg_dist_node ADD COLUMN hasmetadata bool NOT NULL DEFAULT false;
+/* citus--6.0-9--6.0-10.sql */
+
+CREATE TABLE citus.pg_dist_transaction (
+    groupid int NOT NULL,
+    gid text NOT NULL
+);
+
+CREATE INDEX pg_dist_transaction_group_index
+ON citus.pg_dist_transaction using btree(groupid);
+
+ALTER TABLE citus.pg_dist_transaction SET SCHEMA pg_catalog;
+ALTER TABLE pg_catalog.pg_dist_transaction
+ADD CONSTRAINT pg_dist_transaction_unique_constraint UNIQUE (groupid, gid);
+
+GRANT SELECT ON pg_catalog.pg_dist_transaction TO public;
+
+CREATE FUNCTION recover_prepared_transactions()
+    RETURNS int
+    LANGUAGE C STRICT
+    AS 'MODULE_PATHNAME', $$recover_prepared_transactions$$;
+
+COMMENT ON FUNCTION recover_prepared_transactions()
+    IS 'recover prepared transactions started by this node';
+
+/* citus--6.0-10--6.0-11.sql */
+
+SET search_path = 'pg_catalog';
+
+CREATE SEQUENCE citus.pg_dist_colocationid_seq
+	MINVALUE 1
+	MAXVALUE 4294967296;
+
+ALTER SEQUENCE citus.pg_dist_colocationid_seq SET SCHEMA pg_catalog;
+
+/* add pg_dist_colocation */
+CREATE TABLE citus.pg_dist_colocation(
+	colocationid int NOT NULL PRIMARY KEY,
+	shardcount int NOT NULL,
+	replicationfactor int NOT NULL,
+	distributioncolumntype oid NOT NULL
+);
+
+ALTER TABLE citus.pg_dist_colocation SET SCHEMA pg_catalog;
+
+CREATE INDEX pg_dist_colocation_configuration_index
+ON pg_dist_colocation USING btree(shardcount, replicationfactor, distributioncolumntype);
+
+CREATE FUNCTION create_distributed_table(table_name regclass,
+										 distribution_column text,
+										 distribution_type citus.distribution_type DEFAULT 'hash')
+    RETURNS void
+    LANGUAGE C STRICT
+    AS 'MODULE_PATHNAME', $$create_distributed_table$$;
+COMMENT ON FUNCTION create_distributed_table(table_name regclass,
+											 distribution_column text,
+											 distribution_type citus.distribution_type)
+    IS 'creates a distributed table';
+
+
+CREATE OR REPLACE FUNCTION pg_catalog.citus_drop_trigger()
+    RETURNS event_trigger
+    LANGUAGE plpgsql
+    SECURITY DEFINER
+    SET search_path = pg_catalog
+    AS $cdbdt$
+DECLARE
+    v_obj record;
+    sequence_names text[] := '{}';
+    node_names text[] := '{}';
+    node_ports bigint[] := '{}';
+    node_name text;
+    node_port bigint;
+    table_colocation_id integer;
+BEGIN
+    -- collect set of dropped sequences to drop on workers later
+    SELECT array_agg(object_identity) INTO sequence_names
+    FROM pg_event_trigger_dropped_objects()
+    WHERE object_type = 'sequence';
+
+    -- Must accumulate set of affected nodes before deleting placements, as
+    -- master_drop_all_shards will erase their rows, making it impossible for
+    -- us to know where to drop sequences (which must be dropped after shards,
+    -- since they have default value expressions which depend on sequences).
+    SELECT array_agg(sp.nodename), array_agg(sp.nodeport)
+    INTO node_names, node_ports
+    FROM pg_event_trigger_dropped_objects() AS dobj,
+         pg_dist_shard AS s,
+         pg_dist_shard_placement AS sp
+    WHERE dobj.object_type IN ('table', 'foreign table')
+      AND dobj.objid = s.logicalrelid
+      AND s.shardid = sp.shardid;
+
+    FOR v_obj IN SELECT * FROM pg_event_trigger_dropped_objects() LOOP
+        IF v_obj.object_type NOT IN ('table', 'foreign table') THEN
+           CONTINUE;
+        END IF;
+
+        -- nothing to do if not a distributed table
+        IF NOT EXISTS(SELECT * FROM pg_dist_partition WHERE logicalrelid = v_obj.objid) THEN
+            CONTINUE;
+        END IF;
+
+        -- ensure all shards are dropped
+        PERFORM master_drop_all_shards(v_obj.objid, v_obj.schema_name, v_obj.object_name);
+
+        -- get colocation group
+        SELECT colocationid INTO table_colocation_id FROM pg_dist_partition WHERE logicalrelid = v_obj.objid;
+
+        -- delete partition entry
+        DELETE FROM pg_dist_partition WHERE logicalrelid = v_obj.objid;
+
+        -- drop colocation group if all referencing tables are dropped
+        IF NOT EXISTS(SELECT * FROM pg_dist_partition WHERE colocationId = table_colocation_id) THEN
+            DELETE FROM pg_dist_colocation WHERE colocationId = table_colocation_id;
+        END IF;
+    END LOOP;
+
+    IF cardinality(sequence_names) = 0 THEN
+        RETURN;
+    END IF;
+
+    FOR node_name, node_port IN
+    SELECT DISTINCT name, port
+    FROM unnest(node_names, node_ports) AS nodes(name, port)
+    LOOP
+        PERFORM master_drop_sequences(sequence_names, node_name, node_port);
+    END LOOP;
+END;
+$cdbdt$;
+
+COMMENT ON FUNCTION citus_drop_trigger()
+    IS 'perform checks and actions at the end of DROP actions';
+
+ALTER TABLE pg_dist_partition ALTER COLUMN colocationid TYPE integer;
+
+RESET search_path;
+/* citus--6.0-11--6.0-12.sql */
+
+SET search_path = 'pg_catalog';
+
+CREATE FUNCTION create_reference_table(table_name regclass)
+	RETURNS void
+	LANGUAGE C STRICT
+	AS 'MODULE_PATHNAME', $$create_reference_table$$;
+COMMENT ON FUNCTION create_reference_table(table_name regclass)
+	IS 'create a distributed reference table';
+
+RESET search_path;
+/* citus--6.0-12--6.0-13.sql */
+
+CREATE FUNCTION pg_catalog.worker_apply_inter_shard_ddl_command(referencing_shard bigint,
+																referencing_schema_name text,
+																referenced_shard bigint,
+																referenced_schema_name text,
+																command text)
+    RETURNS void
+    LANGUAGE C STRICT
+    AS 'MODULE_PATHNAME', $$worker_apply_inter_shard_ddl_command$$;
+COMMENT ON FUNCTION pg_catalog.worker_apply_inter_shard_ddl_command(referencing_shard bigint,
+																	referencing_schema_name text,
+																	referenced_shard bigint,
+																	referenced_schema_name text,
+																	command text)
+    IS 'executes inter shard ddl command';
+/* citus--6.0-13--6.0-14.sql */
+
+DO $ff$
+BEGIN
+	-- fix functions created in wrong namespace
+	ALTER FUNCTION public.recover_prepared_transactions()
+	SET SCHEMA pg_catalog;
+
+	ALTER FUNCTION public.column_name_to_column(table_name regclass, column_name text)
+	SET SCHEMA pg_catalog;
+
+	ALTER FUNCTION public.worker_drop_distributed_table(logicalrelid Oid)
+	SET SCHEMA pg_catalog;
+
+	ALTER FUNCTION public.master_get_new_placementid()
+	SET SCHEMA pg_catalog;
+
+	ALTER FUNCTION public.master_expire_table_cache(table_name regclass)
+	SET SCHEMA pg_catalog;
+
+-- some installations don't need this corrective, so just skip...
+EXCEPTION WHEN undefined_function THEN
+	-- do nothing
+END
+$ff$;
+/* citus--6.0-14--6.0-15.sql */
+
+
+CREATE FUNCTION pg_catalog.master_dist_placement_cache_invalidate()
+    RETURNS trigger
+    LANGUAGE C
+    AS 'MODULE_PATHNAME', $$master_dist_placement_cache_invalidate$$;
+COMMENT ON FUNCTION master_dist_placement_cache_invalidate()
+    IS 'register relcache invalidation for changed placements';
+
+CREATE TRIGGER dist_placement_cache_invalidate
+    AFTER INSERT OR UPDATE OR DELETE
+    ON pg_catalog.pg_dist_shard_placement
+    FOR EACH ROW EXECUTE PROCEDURE master_dist_placement_cache_invalidate();
+/* citus--6.0-15--6.0-16.sql */
+
+SET search_path = 'pg_catalog';
+
+CREATE FUNCTION mark_tables_colocated(source_table_name regclass, target_table_names regclass[])
+	RETURNS void
+	LANGUAGE C STRICT
+	AS 'MODULE_PATHNAME', $$mark_tables_colocated$$;
+COMMENT ON FUNCTION mark_tables_colocated(source_table_name regclass, target_table_names regclass[])
+	IS 'mark target distributed tables as colocated with the source table';
+
+RESET search_path;
